[PATCH] We don't want double buffering in pbuffer mode.

Roderick Colenbrander thunderbird2k at gmx.net
Thu May 1 08:26:02 CDT 2008


---
 dlls/wined3d/context.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/dlls/wined3d/context.c b/dlls/wined3d/context.c
index dcce127..e5b82e5 100644
--- a/dlls/wined3d/context.c
+++ b/dlls/wined3d/context.c
@@ -148,8 +148,8 @@ static int WineD3D_ChoosePixelFormat(IWineD3DDeviceImpl *This, HDC hdc, WINED3DF
         if(auxBuffers && !cfgs->auxBuffers)
             continue;
 
-        /* In pbuffer-mode we need a pbuffer-capable format */
-        if(pbuffer && !cfgs->pbufferDrawable)
+        /* In pbuffer-mode we need a pbuffer-capable format but we don't want double buffering */
+        if(pbuffer && (!cfgs->pbufferDrawable || cfgs->doubleBuffer))
             continue;
 
         if(cfgs->redSize != redBits)
-- 
1.5.3.4


--========GMX327141209641716936995--



More information about the wine-patches mailing list